@@ -24,7 +24,7 @@ use Storable qw(dclone);
 
 use DateTime::Format::Natural::Utils qw(trim);
 
-our $VERSION = '1.16_01';
+our $VERSION = '1.17_01';
 
 validation_options(
     on_fail => sub
@@ -853,7 +853,7 @@ recognized by L<DateTime>. Defaults to 'floating'.
 
 =item * C<daytime>
 
-An anonymous hash reference consisting of customized daytime hours,
+A hash reference consisting of customized daytime hours,
 which may be selectively changed.
 
 =back
@@ -990,7 +990,6 @@ valuable suggestions and patches:
  Jim Avera
  Olaf Alders
  Karen Etheridge
- Giovanni Pensa
 
 =head1 SEE ALSO
 
